@@ -155,4 +155,4 @@ class StudiogdoApi(object):
 
             return response
         except:
-            raise Exception("studiogdo service not available")
+            raise Exception("studiogdo service not available\n%s" % self.root_address)
